@@ -2,12 +2,13 @@ import os, sys, inspect
 import pkg_resources
 
 #Pour inclure les fichiers de l'environnement
+'''
 cmd_subfolder_grid = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"Grid")))
 if cmd_subfolder_grid not in sys.path:
     sys.path.insert(0, cmd_subfolder_grid)
-
-from grid import Grid
-from parser import Parser
+'''
+from .grid import Grid
+from .parser import Parser
 
 import random
 import math
